@@ -22,7 +22,6 @@ import sys
 import mimetypes as mime
 
 # Third party imports
-from qtpy import API, is_pyqt46
 from qtpy.compat import getsavefilename, getexistingdirectory
 from qtpy.QtCore import (QDir, QFileInfo, QMimeData, QSize,
                          QSortFilterProxyModel, Qt, QTimer, QUrl,
@@ -33,7 +32,7 @@ from qtpy.QtWidgets import (QFileSystemModel, QHBoxLayout, QFileIconProvider,
                             QMessageBox, QToolButton, QTreeView, QVBoxLayout,
                             QWidget)
 # Local imports
-from spyder.config.base import _
+from spyder.config.base import _, get_home_dir
 from spyder.py3compat import (str_lower, to_binary_string,
                               to_text_string)
 from spyder.utils import icon_manager as ima
@@ -77,8 +76,13 @@ def fixpath(path):
 def create_script(fname):
     """Create a new Python script"""
     text = os.linesep.join(["# -*- coding: utf-8 -*-", "", ""])
-    encoding.write(to_text_string(text), fname, 'utf-8')
-
+    try:
+        encoding.write(to_text_string(text), fname, 'utf-8')
+    except EnvironmentError as error:
+        QMessageBox.critical(_("Save Error"),
+                             _("<b>Unable to save file '%s'</b>"
+                               "<br><br>Error message:<br>%s"
+                               ) % (osp.basename(fname), str(error)))
 
 def listdir(path, include=r'.', exclude=r'\.pyc$|^\.', show_all=False,
             folders_only=False):
@@ -207,9 +211,8 @@ class DirView(QTreeView):
     def setup_view(self):
         """Setup view"""
         self.install_model()
-        if not is_pyqt46:
-            self.fsmodel.directoryLoaded.connect(
-                                        lambda: self.resizeColumnToContents(0))
+        self.fsmodel.directoryLoaded.connect(
+            lambda: self.resizeColumnToContents(0))
         self.setAnimated(False)
         self.setSortingEnabled(True)
         self.sortByColumn(0, Qt.AscendingOrder)
@@ -386,16 +389,10 @@ class DirView(QTreeView):
         dirname = fnames[0] if osp.isdir(fnames[0]) else osp.dirname(fnames[0])
         if len(fnames) == 1 and vcs.is_vcs_repository(dirname):
             # QAction.triggered works differently for PySide and PyQt
-            if not API == 'pyside':
-                commit_slot = lambda _checked, fnames=[dirname]:\
-                                    self.vcs_command(fnames, 'commit')
-                browse_slot = lambda _checked, fnames=[dirname]:\
-                                    self.vcs_command(fnames, 'browse')
-            else:
-                commit_slot = lambda fnames=[dirname]:\
-                                    self.vcs_command(fnames, 'commit')
-                browse_slot = lambda fnames=[dirname]:\
-                                    self.vcs_command(fnames, 'browse')
+            commit_slot = lambda fnames=[dirname]:\
+                                self.vcs_command(fnames, 'commit')
+            browse_slot = lambda fnames=[dirname]:\
+                                self.vcs_command(fnames, 'browse')
             vcs_ci = create_action(self, _("Commit"),
                                    icon=ima.icon('vcs_commit'),
                                    triggered=commit_slot)
@@ -477,8 +474,13 @@ class DirView(QTreeView):
                 
     def contextMenuEvent(self, event):
         """Override Qt method"""
-        self.update_menu()
-        self.menu.popup(event.globalPos())
+        # Needed to handle not initialized menu.
+        # See issue 6975
+        try:
+            self.update_menu()
+            self.menu.popup(event.globalPos())
+        except AttributeError:
+            pass
 
     def keyPressEvent(self, event):
         """Reimplement Qt method"""
@@ -668,7 +670,10 @@ class DirView(QTreeView):
                     return
             try:
                 misc.rename_file(fname, path)
-                self.parent_widget.renamed.emit(fname, path)
+                if osp.isfile(fname):
+                    self.parent_widget.renamed.emit(fname, path)
+                else:
+                    self.parent_widget.renamed_tree.emit(fname, path)
                 return path
             except EnvironmentError as error:
                 QMessageBox.critical(self, _("Rename"),
@@ -881,7 +886,7 @@ class DirView(QTreeView):
                     self._to_be_loaded = []
                 self._to_be_loaded.append(path)
                 self.setExpanded(self.get_index(path), True)
-        if not self.__expanded_state and not is_pyqt46:
+        if not self.__expanded_state:
             self.fsmodel.directoryLoaded.disconnect(self.restore_directory_state)
                 
     def follow_directories_loaded(self, fname):
@@ -891,8 +896,7 @@ class DirView(QTreeView):
         path = osp.normpath(to_text_string(fname))
         if path in self._to_be_loaded:
             self._to_be_loaded.remove(path)
-        if self._to_be_loaded is not None and len(self._to_be_loaded) == 0 \
-          and not is_pyqt46:
+        if self._to_be_loaded is not None and len(self._to_be_loaded) == 0:
             self.fsmodel.directoryLoaded.disconnect(
                                         self.follow_directories_loaded)
             if self._scrollbar_positions is not None:
@@ -903,7 +907,7 @@ class DirView(QTreeView):
         """Restore all items expanded state"""
         if self.__expanded_state is not None:
             # In the old project explorer, the expanded state was a dictionnary:
-            if isinstance(self.__expanded_state, list) and not is_pyqt46:
+            if isinstance(self.__expanded_state, list):
                 self.fsmodel.directoryLoaded.connect(
                                                   self.restore_directory_state)
                 self.fsmodel.directoryLoaded.connect(
@@ -1118,9 +1122,13 @@ class ExplorerTreeWidget(DirView):
         
     def update_history(self, directory):
         """Update browse history"""
-        directory = osp.abspath(to_text_string(directory))
-        if directory in self.history:
-            self.histindex = self.history.index(directory)
+        try:
+            directory = osp.abspath(to_text_string(directory))
+            if directory in self.history:
+                self.histindex = self.history.index(directory)
+        except Exception:
+            user_directory = get_home_dir()
+            self.chdir(directory=user_directory, browsing_history=True)
         
     def chdir(self, directory=None, browsing_history=False):
         """Set directory as working directory"""
