@@ -510,7 +510,7 @@ def test_tab_moves_focus_from_search_to_replace(editor_find_replace_bot):
 
 
 @flaky(max_runs=3)
-@pytest.mark.skipif(platform.startswith('linux'), reason="Fails on Linux.")
+@pytest.mark.skipif(not os.name == 'nt', reason="Fails on Linux and macOS.")
 def test_tab_copies_find_to_replace(editor_find_replace_bot):
     """Check that text in the find box is copied to the replace box on tab
     keypress. Regression test #4482."""
