@@ -18,10 +18,9 @@ from qtpy import API
 from qtpy.compat import from_qvariant, to_qvariant
 from qtpy.QtCore import QAbstractTableModel, QModelIndex, Qt, Signal, Slot
 from qtpy.QtGui import QColor, QCursor
-from qtpy.QtWidgets import (QApplication, QCheckBox, QDialogButtonBox, QDialog,
-                            QGridLayout, QHBoxLayout, QInputDialog, QLineEdit,
-                            QMenu, QMessageBox, QPushButton, QTableView,
-                            QHeaderView)
+from qtpy.QtWidgets import (QApplication, QCheckBox, QDialog, QGridLayout,
+                            QHBoxLayout, QInputDialog, QLineEdit, QMenu,
+                            QMessageBox, QPushButton, QTableView, QHeaderView)
 
 from pandas import DataFrame, DatetimeIndex, Series
 try:
@@ -34,9 +33,8 @@ import numpy as np
 from spyder.config.base import _
 from spyder.config.fonts import DEFAULT_SMALL_DELTA
 from spyder.config.gui import get_font, config_shortcut
-from spyder.py3compat import (io, is_text_string, PY2, to_text_string,
-                              TEXT_TYPES)
-from spyder.utils import encoding
+from spyder.py3compat import (io, is_text_string, is_type_text_string, PY2,
+                              to_text_string)
 from spyder.utils import icon_manager as ima
 from spyder.utils.qthelpers import (add_actions, create_action,
                                     keybinding, qapplication)
@@ -195,31 +193,26 @@ class DataFrameModel(QAbstractTableModel):
             if section == 0:
                 return 'Index'
             elif section == 1 and PY2:
+                header = self.df_header[0]
                 # Get rid of possible BOM utf-8 data present at the
                 # beginning of a file, which gets attached to the first
                 # column header when headers are present in the first
                 # row.
                 # Fixes Issue 2514
                 try:
-                    header = to_text_string(self.df_header[0],
-                                            encoding='utf-8-sig')
+                    header = to_text_string(header, encoding='utf-8-sig')
                 except:
-                    header = to_text_string(self.df_header[0])
+                    # Don't perform any conversion on strings because it
+                    # leads to differences between the data present in
+                    # the dataframe and what is shown by Spyder
+                    if not is_type_text_string(header):
+                        header = to_text_string(header)
                 return to_qvariant(header)
-            elif isinstance(self.df_header[section-1], TEXT_TYPES):
-                # Get the proper encoding of the text in the header.
-                # Fixes Issue 3896
-                if not PY2:
-                    try:
-                        header = self.df_header[section-1].encode('utf-8')
-                        coding = 'utf-8-sig'
-                    except:
-                        header = self.df_header[section-1].encode('utf-8')
-                        coding = encoding.get_coding(header)
-                else:
-                    header = self.df_header[section-1]
-                    coding = encoding.get_coding(header)
-                return to_qvariant(to_text_string(header, encoding=coding))
+            elif is_type_text_string(self.df_header[section-1]):
+                # Don't perform any conversion on strings because it
+                # leads to differences between the data present in
+                # the dataframe and what is shown by Spyder
+                return to_qvariant(self.df_header[section-1])
             else:
                 return to_qvariant(to_text_string(self.df_header[section-1]))
         else:
@@ -280,7 +273,15 @@ class DataFrameModel(QAbstractTableModel):
             column = index.column()
             row = index.row()
             if column == 0:
-                return to_qvariant(to_text_string(self.df_index[row]))
+                df_idx = self.df_index[row]
+                if is_type_text_string(df_idx):
+                    # Don't perform any conversion on strings
+                    # because it leads to differences between
+                    # the data present in the dataframe and
+                    # what is shown by Spyder
+                    return df_idx
+                else:
+                    return to_qvariant(to_text_string(df_idx))
             else:
                 value = self.get_value(row, column-1)
                 if isinstance(value, float):
@@ -290,11 +291,14 @@ class DataFrameModel(QAbstractTableModel):
                         # may happen if format = '%d' and value = NaN;
                         # see issue 4139
                         return to_qvariant(DEFAULT_FORMAT % value)
+                elif is_type_text_string(value):
+                    # Don't perform any conversion on strings
+                    # because it leads to differences between
+                    # the data present in the dataframe and
+                    # what is shown by Spyder
+                    return value
                 else:
-                    try:
-                        return to_qvariant(to_text_string(value))
-                    except UnicodeDecodeError:
-                        return to_qvariant(encoding.to_unicode(value))
+                    return to_qvariant(to_text_string(value))
         elif role == Qt.BackgroundColorRole:
             return to_qvariant(self.get_bgcolor(index))
         elif role == Qt.FontRole:
@@ -382,6 +386,7 @@ class DataFrameModel(QAbstractTableModel):
                                      .format(type(current_value).__name__))
                 return False
         self.max_min_col_update()
+        self.dataChanged.emit(index, index)
         return True
 
     def get_data(self):
@@ -441,7 +446,7 @@ class DataFrameModel(QAbstractTableModel):
 class FrozenTableView(QTableView):
     """This class implements a table with its first column frozen
     For more information please see:
-    http://doc.qt.io/qt-5/qtwidgets-itemviews-frozencolumn-example.html"""
+    https://doc.qt.io/qt-5/qtwidgets-itemviews-frozencolumn-example.html"""
     def __init__(self, parent):
         """Constructor."""
         QTableView.__init__(self, parent)
@@ -691,6 +696,7 @@ class DataFrameEditor(QDialog):
         self.resize(600, 500)
 
         self.dataModel = DataFrameModel(data, parent=self)
+        self.dataModel.dataChanged.connect(self.save_and_close_enable)
         self.dataTable = DataFrameView(self, self.dataModel)
 
         self.layout.addWidget(self.dataTable)
@@ -722,15 +728,29 @@ class DataFrameEditor(QDialog):
         btn_layout.addWidget(self.bgcolor_global)
 
         btn_layout.addStretch()
-        bbox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
-        bbox.accepted.connect(self.accept)
-        bbox.rejected.connect(self.reject)
-        btn_layout.addWidget(bbox)
+
+        self.btn_save_and_close = QPushButton(_('Save and Close'))
+        self.btn_save_and_close.setDisabled(True)
+        self.btn_save_and_close.clicked.connect(self.accept)
+        btn_layout.addWidget(self.btn_save_and_close)
+
+        self.btn_close = QPushButton(_('Close'))
+        self.btn_close.setAutoDefault(True)
+        self.btn_close.setDefault(True)
+        self.btn_close.clicked.connect(self.reject)
+        btn_layout.addWidget(self.btn_close)
 
         self.layout.addLayout(btn_layout, 2, 0)
 
         return True
 
+    @Slot(QModelIndex, QModelIndex)
+    def save_and_close_enable(self, top_left, bottom_right):
+        """Handle the data change event to enable the save and close button."""
+        self.btn_save_and_close.setEnabled(True)
+        self.btn_save_and_close.setAutoDefault(True)
+        self.btn_save_and_close.setDefault(True)
+
     def change_bgcolor_enable(self, state):
         """
         This is implementet so column min/max is only active when bgcolor is
